pub enum FrequencyLimitError {
ValueBelowMinimum(f32),
ValueAboveNyquist(f32),
InvalidRange(f32, f32),
}Expand description
Possible errors when creating a FrequencyLimit-object.
Variants
ValueBelowMinimum(f32)
If the minimum value is below 0. Negative frequencies are not supported.
ValueAboveNyquist(f32)
If the maximum value is above Nyquist frequency. Nyquist-Frequency is the maximum detectable frequency.
InvalidRange(f32, f32)
Either the corresponding value is below or above the minimum/maximum or the first member of the tuple is bigger than the second.