pub enum SpectrumAnalyzerError {
InvalidLengthOfSamples,
InvalidSamplingRate,
NaNValuesNotSupported,
InfinityValuesNotSupported,
InvalidFrequencyLimit(FrequencyLimitError),
FrequencyLimitTooNarrow,
ScalingError(f32, f32),
}Expand description
Describes main errors of the library. Almost all errors are caused by wrong input.
Variants
InvalidLengthOfSamples
The amount of samples must be a power of 2, at least 2, and no more than 32768.
InvalidSamplingRate
The sampling rate must not be zero.
NaNValuesNotSupported
NaN values in samples are not supported!
InfinityValuesNotSupported
Infinity-values (regarding floating point representation) in samples are not supported!
InvalidFrequencyLimit(FrequencyLimitError)
The frequency is invalid. See FrequencyLimitError.
FrequencyLimitTooNarrow
The frequency limit is valid in isolation but leaves too few frequency bins for a spectrum.
ScalingError(f32, f32)
After applying the scaling function on a specific item, the returned value is either infinity or NaN, according to IEEE-754. This is invalid. Check your scaling function!