pub struct SpectrumDataStats {
pub min: FrequencyValue,
pub max: FrequencyValue,
pub average: FrequencyValue,
pub n: f32,
}Expand description
Helper struct for SpectrumScalingFunction that is passed into the
scaling function together with the current frequency value.
This structure can be used to scale each value. All properties reference the
current data of a FrequencySpectrum.
Fields
min: FrequencyValueMinimal frequency value in spectrum.
max: FrequencyValueMaximum frequency value in spectrum.
average: FrequencyValueAverage frequency value in spectrum.
n: f32Number of samples (samples.len()), not the number of values in the
spectrum (which can be smaller due to a frequency limit).