Crate spectrum_analyzer[−][src]
Simple no_std spectrum analysis library that follows the KISS (keep it simple, stupid)
principle. The main goal of this crate is to be educational to the world and myself. This
is not a bullet-proof or ideal solution! Feel free to contribute and point out possible
errors/bugs/wrong assumptions or improvements!
Modules
| windows | Several window functions which you can apply before doing the FFT. For more information: |
Structs
| FrequencySpectrum |
Enums
| FrequencyLimit | Can be used to specify a desired frequency limit. If you know that you only
need frequencies |
Functions
| samples_fft_to_spectrum | Takes an array of samples (length must be a power of 2),
e.g. 2048, applies an FFT (using library |
Type Definitions
| Frequency | A frequency. A convenient wrapper type around |
| FrequencyValue | The value of a frequency in a frequency spectrum. Convenient wrapper around |
| SpectrumTotalScaleFunctionFactory | Describes the type for a function factory that generates a function that can scale/normalize
the data inside |