pub enum FrequencyLimit {
All,
Min(NonNegF32),
Max(NonNegF32),
Range(NonNegF32, NonNegF32),
}Expand description
Can be used to specify a desired frequency limit.
If you know that you only need frequencies f <= 1000Hz,
1000 <= f <= 6777, or 10000 <= f, then this can help you to accelerate
overall computation speed and memory usage.
Please note that due to frequency inaccuracies the FFT result may not contain
a value for 1000Hz but for 998.76Hz!
Variants
All
Interested in all frequencies, including the DC component up to the Nyquist frequency. In other words, no limit at all.
Min(NonNegF32)
Lower bound: only interested in frequencies >= x. Limit is
inclusive. Supported values are 0 <= x <= Nyquist-Frequency.
Max(NonNegF32)
Upper bound: only interested in frequencies <= x. Limit is
inclusive. Supported values are 0 <= x <= Nyquist-Frequency.
Range(NonNegF32, NonNegF32)
Only interested in frequencies 1000 <= f <= 6777 for example. Both values are inclusive.
The first value of the tuple is equivalent to FrequencyLimit::Min and the latter
equivalent to FrequencyLimit::Max. Furthermore, the first value must not be
bigger than the second value.
Implementations
Sourceimpl FrequencyLimit
impl FrequencyLimit