pub type FrequencyValue = FiniteF32;Expand description
The value of a Frequency in a frequency spectrum.
It is the magnitude of the FFT result at that frequency, optionally
scaled. A scaling function can make it negative, for example
crate::scaling::scale_20_times_log10.
See crate::samples_fft_to_spectrum for what this means in practice.
Aliased Type
pub struct FrequencyValue(/* private fields */);