Type Definition spectrum_analyzer::FrequencyValue
source · pub type FrequencyValue = OrderableF32;Expand description
The value of a Frequency in a frequency spectrum. Also called the
magnitude.
pub type FrequencyValue = OrderableF32;The value of a Frequency in a frequency spectrum. Also called the
magnitude.